@@ -5,6 +5,7 @@ from typing import Dict, Optional
 
 from pydantic.types import UUID4
 
+import dataquality
 from dataquality.clients.api import ApiClient
 from dataquality.core._config import config
 from dataquality.core.auth import login
@@ -25,10 +26,15 @@ class _Init:
     ) -> Dict:
         return api_client.get_project_run_by_name(project_name, run_name)
 
-    def _initialize_new_project(self, project_name: str) -> Dict:
-        print(f"✨ Initializing project {project_name}")
+    def _initialize_new_project(
+        self, project_name: str, is_public: bool = True
+    ) -> Dict:
+        visability = "public" if is_public else "private"
+        print(f"✨ Initializing {visability} project {project_name}")
         try:
-            return api_client.create_project(project_name=project_name)
+            return api_client.create_project(
+                project_name=project_name, is_public=is_public
+            )
         except GalileoException as e:
             if "A project with this name already exists" in str(e):
                 return api_client.get_project_by_name(project_name)
@@ -55,6 +61,7 @@ def init(
     task_type: str,
     project_name: Optional[str] = None,
     run_name: Optional[str] = None,
+    is_public: bool = True,
     overwrite_local: bool = True,
 ) -> None:
     """
@@ -74,6 +81,7 @@ def init(
     :param run_name: The run name. If not passed in, a random one will be
     generated. If provided, and the project does not exist, it will be created. If it
     does exist, it will be set.
+    :param is_public: Boolean value that sets the project's visibility. Default True.
     :param overwrite_local: If True, the current project/run log directory will be
     cleared during this function. If logging over many sessions with checkpoints, you
     may want to set this to False. Default True
@@ -87,7 +95,9 @@ def init(
     if not project_name and not run_name:
         # no project and no run id, start a new project and start a new run
         project_name, run_name = random_name(), random_name()
-        project_response = _init._initialize_new_project(project_name=project_name)
+        project_response = _init._initialize_new_project(
+            project_name=project_name, is_public=is_public
+        )
         run_response = _init._initialize_run_for_project(
             project_name=project_name, run_name=run_name, task_type=task_type
         )
@@ -112,7 +122,9 @@ def init(
         else:
             print(f"💭 Project {project_name} was not found.")
             run_name = random_name()
-            project_response = _init._initialize_new_project(project_name=project_name)
+            project_response = _init._initialize_new_project(
+                project_name=project_name, is_public=is_public
+            )
             run_response = _init._initialize_run_for_project(
                 project_name=project_name, run_name=run_name, task_type=task_type
             )
@@ -149,7 +161,9 @@ def init(
         else:
             # User gave us a new project name and new run name to create, so create it
             print(f"💭 Project {project_name} was not found.")
-            project_response = _init._initialize_new_project(project_name=project_name)
+            project_response = _init._initialize_new_project(
+                project_name=project_name, is_public=is_public
+            )
             run_response = _init._initialize_run_for_project(
                 project_name=project_name, run_name=run_name, task_type=task_type
             )
@@ -170,3 +184,5 @@ def init(
             config.current_run_id,
             overwrite_local=overwrite_local,
         )
+    # Reset all config variables
+    dataquality.get_data_logger().logger_config.reset()
