@@ -1,3 +1,4 @@
+import warnings
 from collections import defaultdict
 from enum import Enum, unique
 from typing import Any, Dict, List, Optional, Union
@@ -16,6 +17,7 @@ from dataquality.schemas.split import Split
 class GalileoModelLoggerAttributes(str, Enum):
     emb = "emb"
     probs = "probs"
+    logits = "logits"
     ids = "ids"
     # mixin restriction on str (due to "str".split(...))
     split = "split"  # type: ignore
@@ -30,23 +32,29 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
     """
     Class for logging model output data of Text Classification models to Galileo.
 
-    * emb: List[Union[List, np.ndarray, torch.Tensor, tf.Tensor]]. The Embeddings per
+    * emb: Union[List, np.ndarray, torch.Tensor, tf.Tensor]. The Embeddings per
     text sample input. Only one embedding vector is allowed per input sample.
     the `emb` parameter can be formatted either as:
+        * np.ndarray
+        * torch.tensor / tf.tensor
         * A list of List[float]
         * A list of numpy arrays
         * A list of tensorflow tensors
         * A list of pytorch tensors
-    * prob: List[Union[List, np.ndarray, torch.Tensor, tf.Tensor]] probabilities from
-    forward passes during model training/evaluation.
-    the `prob` parameter can be formatted either as:
+    * logits: Union[List, np.ndarray, torch.Tensor, tf.Tensor] outputs from
+     forward pass. If provided, probs will be converted automatically and DO NOT need
+     to be provided. Can be formatted either as:
+        * np.ndarray
+        * torch.tensor / tf.tensor
         * A list of List[float]
         * A list of numpy arrays
         * A list of tensorflow tensors
         * A list of pytorch tensors
+    * probs: Deprecated - the probabilities for each output sample (use logits instead)
     * ids: Indexes of each input field: List[int]. These IDs must align with the input
     IDs for each sample input. This will be used to join them together for analysis
     by Galileo.
+    * split: The model training/test/validation split for the samples being logged
     """
 
     __logger_name__ = "text_classification"
@@ -56,6 +64,7 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         self,
         emb: Union[List, np.ndarray] = None,
         probs: Union[List, np.ndarray] = None,
+        logits: Union[List, np.ndarray] = None,
         ids: Union[List, np.ndarray] = None,
         split: str = "",
         epoch: Optional[int] = None,
@@ -63,16 +72,17 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         super().__init__()
         # Need to compare to None because they may be np arrays which cannot be
         # evaluated with bool directly
-        self.emb = emb if emb is not None else []
-        self.probs = probs if probs is not None else []
-        self.ids = ids if ids is not None else []
+        self.emb: Union[List, np.ndarray] = emb if emb is not None else []
+        self.logits: Union[List, np.ndarray] = logits if logits is not None else []
+        self.probs: Union[List, np.ndarray] = probs if probs is not None else []
+        self.ids: Union[List, np.ndarray] = ids if ids is not None else []
         self.split: str = split
         self.epoch = epoch
 
     @staticmethod
     def get_valid_attributes() -> List[str]:
         """
-        Returns a list of valid attributes that GalileoModelConfig accepts
+        Returns a list of valid attributes that this logger accepts
         :return: List[str]
         """
         return GalileoModelLoggerAttributes.get_valid()
@@ -83,29 +93,32 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         * emb, probs, and ids must exist and be the same length
         :return:
         """
+        super().validate()
+
+        if len(self.logits):
+            self.logits = self._convert_tensor_ndarray(self.logits, "Prob")
+            self.probs = self.convert_logits_to_probs(self.logits)
+            del self.logits
+        elif len(self.probs):
+            warnings.warn("Usage of probs is deprecated, use logits instead")
+            self.probs = self._convert_tensor_ndarray(self.probs, "Prob")
+
         emb_len = len(self.emb)
         prob_len = len(self.probs)
         id_len = len(self.ids)
 
-        # We add validation here instead of requiring the params at init because
-        # for lightning callbacks, we add these automatically for the user, so they
-        # can create the config in their training loop and we will manage this metadata
-        assert self.split, "Your GalileoModelConfig has no split!"
-        assert self.epoch is not None, "Your GalileoModelConfig has no epoch!"
-
         self.emb = self._convert_tensor_ndarray(self.emb, "Embedding")
-        self.probs = self._convert_tensor_ndarray(self.probs, "Prob")
         self.ids = self._convert_tensor_ndarray(self.ids)
 
         assert self.emb.ndim == 2, "Only one embedding vector is allowed per input."
 
         assert emb_len and prob_len and id_len, (
-            f"All of emb, probs, and ids for your GalileoModelConfig must be set, but "
+            f"All of emb, probs, and ids for your logger must be set, but "
             f"got emb:{bool(emb_len)}, probs:{bool(prob_len)}, ids:{bool(id_len)}"
         )
 
         assert emb_len == prob_len == id_len, (
-            f"All of emb, probs, and ids for your GalileoModelConfig must be the same "
+            f"All of emb, probs, and ids for your logger must be the same "
             f"length, but got (emb, probs, ids) -> ({emb_len},{prob_len}, {id_len})"
         )
 
